Test Execution Report

## Help

### Filters

- d Toggle filter [Delta only]
- p Toggle filter [Passed]
- f Toggle filter [Failed]
- e Toggle filter [Error]
- c Toggle filter [Crashed]
- s Toggle filter [Skipped]
- r Toggle filter [Running]
- q Toggle filter [Queued]

### Logs

- l Toggle log popup

### Move

- k Next log
- j Previous log

### Other

- h Show help
- esc Close popups

# Test Execution Report

Status: [[status]]
Workers: [[workers_active]] active / [[workers_total]] total
Duration: [[total_duration]]
Sum Duration: [[total_summed_duration]]
Total Memory: [[total_memory]]
Updated at: [[finishing_time]]
Passed: [[passed]] | Failed: [[failed]] | Errors: [[errors]] | Crashed: [[crashed]] | Skipped: [[skipped]] | Running: [[running]] | Queued: [[remaining]]
Comparison: [[regressions]] regressions [[fixed]] fixed [[new_tests]] new [[baseline_info_html]] [[commit_info_html]] [[ci_info_html]]
[[progress_percent]]%
Delta only
Passed Failed Error Crashed Skipped Running Queued
Baseline:
Show only available
📋 Logs

File | Class | Function | Params | Outcome | Delta | Duration | Speedup | Memory | Peak Mem | Error | Logs
[[rows]]

Generated at [[timestamp]]